@@ -1,8 +1,7 @@
+use strict;
+
 use threads;
 use threads::shared;
-use Thread::Semaphore;
-
-
 
 ## execute sub for all given argument lists in in parallel
 ##
@@ -14,51 +13,51 @@ use Thread::Semaphore;
 # long as there is one and processes the job. job reservation needs to
 # be synchronized (by lock on shared var $job_count)
 #
+
 sub foreach_par {
     my ($sub_ref,$argument_lists_ref,$thread_num) = @_;
-    
+
     my @argument_lists = @{ $argument_lists_ref };
-    
-    my $job_num=$#argument_lists+1; ## total number of jobs
+
+    my $job_num=scalar(@argument_lists); ## total number of jobs
 
     my $job_count : shared = 0; ## count already started jobs
 
-    my @my_threads;
-    
+    my @workers;
     for (my $i=1; $i<=$thread_num; $i++) {
-	$my_threads[$i]=
-	    threads->create(
- 		sub {
-		    while(1) {
-			# get the job $job_count
-			my $my_job;
-			{
-			    lock($job_count);
-			    $my_job=$job_count;
-			    $job_count++;
-			}
-			
-			## if job number too large then terminate thread
-			if ($my_job >= $job_num) {return;}
-			
-			## start job
-			$sub_ref->(@{ $argument_lists[$my_job] });
-		    }
-		}
-	    );
+        $workers[$i]=
+          threads->create(
+              sub {
+                  while(1) {
+                      # get the job number
+                      my $my_job;
+                      {
+                          lock($job_count);
+                          $my_job=$job_count;
+                          $job_count++;
+                      }
+
+                      ## if job number too large, then terminate thread
+                      if ($my_job >= $job_num) {return;}
+
+                      # run the job
+                      $sub_ref->(@{ $argument_lists[$my_job] });
+                  }
+              }
+         );
     }
 
     for (my $i=1; $i<=$thread_num; $i++) {
- 	$my_threads[$i]->join();
+        $workers[$i]->join();
     }
 }
 
-
 ## generate a thread-unique filename
-sub threadsafe_name($) {
+sub threadsafe_name {
     my ($name) = @_;
-    if (threads->tid()==0) { return $name; }
-    else {return $name.(threads->tid());}
+    my $tid=threads->tid();
+    if ($tid==0) { return $name; }
+    else {return "$name$tid";}
 }
 
 
